@@ -97,6 +97,7 @@ from synapse.rest.client.v1.room import (
 from synapse.rest.client.v1.voip import VoipRestServlet
 from synapse.rest.client.v1.jitsi import JitsiRestServlet
 from synapse.rest.client.v1.notice import NoticeRestServlet
+from synapse.rest.client.v1.notify import NotifyRestServlet
 from synapse.rest.client.v2_alpha import groups, sync, user_directory
 from synapse.rest.client.v2_alpha._base import client_patterns
 from synapse.rest.client.v2_alpha.account import ThreepidRestServlet
@@ -469,6 +470,7 @@ class GenericWorkerServer(HomeServer):
                     VoipRestServlet(self).register(resource)
                     JitsiRestServlet(self).register(resource)
                     NoticeRestServlet(self).register(resource)
+                    NotifyRestServlet(self).register(resource)
                     PushRuleRestServlet(self).register(resource)
                     VersionsRestServlet(self).register(resource)
                     RoomSendEventRestServlet(self).register(resource)
