@@ -47,6 +47,7 @@ from .user_directory import UserDirectoryConfig
 from .voip import VoipConfig
 from .jitsi import JitsiConfig
 from .notice import NoticeConfig
+from .notify import NotifyConfig
 from .workers import WorkerConfig
 
 
@@ -63,6 +64,7 @@ class HomeServerConfig(RootConfig):
         VoipConfig,
         JitsiConfig,
         NoticeConfig,
+        NotifyConfig,
         RegistrationConfig,
         MetricsConfig,
         ApiConfig,
