@@ -30,6 +30,7 @@ from synapse.rest.client.v1 import (
     voip,
     jitsi,
     notice,
+    notify,
 )
 from synapse.rest.client.v2_alpha import (
     account,
@@ -93,6 +94,7 @@ class ClientRestResource(JsonResource):
         voip.register_servlets(hs, client_resource)
         jitsi.register_servlets(hs, client_resource)
         notice.register_servlets(hs, client_resource)
+        notify.register_servlets(hs, client_resource)
         pusher.register_servlets(hs, client_resource)
         push_rule.register_servlets(hs, client_resource)
         logout.register_servlets(hs, client_resource)
