@@ -37,7 +37,7 @@ class NotifyRestServlet(RestServlet):
         return (
             200,
             {
-                "data": notifyUrl,
+                "url": notifyUrl,
             },
         )
 
